@@ -1,7 +1,7 @@
 /*
     This class provides the interface to the libsmbclient library.
 
-    SPDX-FileCopyrightText: 2018-2023 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
+    SPDX-FileCopyrightText: 2018-2025 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -19,6 +19,11 @@
 
 // Qt includes
 #include <QApplication>
+#if (QT_VERSION >= QT_VERSION_CHECK(6,8,0))
+#include <QApplicationStatic>
+#else
+#include <qapplicationstatic.h>
+#endif
 #include <QHostAddress>
 #include <QPointer>
 #include <QTimer>
@@ -26,7 +31,7 @@
 
 using namespace Smb4KGlobal;
 
-Q_GLOBAL_STATIC(Smb4KClientStatic, p);
+Q_APPLICATION_STATIC(Smb4KClientStatic, p);
 
 Smb4KClient::Smb4KClient(QObject *parent)
     : KCompositeJob(parent)
