@@ -1,7 +1,7 @@
 /*
     This is the global namespace for Smb4K.
 
-    SPDX-FileCopyrightText: 2005-2024 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
+    SPDX-FileCopyrightText: 2005-2025 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -15,7 +15,7 @@
 #include "smb4ksynchronizer.h"
 
 // Qt includes
-#if (QT_VERSION >= QT_VERSION_CHECK(6,8,0))
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 8, 0))
 #include <QApplicationStatic>
 #else
 #include <qapplicationstatic.h>
@@ -31,6 +31,7 @@
 // KDE includes
 #include <KIO/CommandLauncherJob>
 #include <KIO/OpenUrlJob>
+#include <KProcess>
 
 Q_APPLICATION_STATIC(Smb4KGlobalPrivate, p);
 QRecursiveMutex mutex;
@@ -639,7 +640,7 @@ bool Smb4KGlobal::updateMountedShare(SharePtr share)
     return updated;
 }
 
-bool Smb4KGlobal::removeMountedShare(SharePtr share)
+bool Smb4KGlobal::removeMountedShare(SharePtr share, bool takeOnly)
 {
     Q_ASSERT(share);
 
@@ -648,12 +649,8 @@ bool Smb4KGlobal::removeMountedShare(SharePtr share)
     if (share) {
         mutex.lock();
 
-        //
-        // Reset the mount data for the network share and the
-        // search result
-        //
+        // Reset the mount data for the _network share_
         if (!share->isForeign()) {
-            // Network share
             SharePtr networkShare = findShare(share->url(), share->workgroupName());
 
             if (networkShare) {
@@ -661,17 +658,12 @@ bool Smb4KGlobal::removeMountedShare(SharePtr share)
             }
         }
 
-        //
-        // Remove the mounted share
-        //
         int index = p->mountedSharesList.indexOf(share);
 
         if (index != -1) {
-            // The share was found. Remove it.
-            p->mountedSharesList.takeAt(index).clear();
+            p->mountedSharesList.takeAt(index);
             removed = true;
         } else {
-            // Try harder to find the share.
             SharePtr s = findShareByPath(share->isInaccessible() ? share->path() : share->canonicalPath());
 
             if (s) {
@@ -682,7 +674,9 @@ bool Smb4KGlobal::removeMountedShare(SharePtr share)
                     removed = true;
                 }
             }
+        }
 
+        if (share && !takeOnly) {
             share.clear();
         }
 
@@ -751,13 +745,6 @@ const QString Smb4KGlobal::machineWorkgroupName()
     return p->machineWorkgroupName;
 }
 
-#if defined(Q_OS_LINUX)
-QStringList Smb4KGlobal::allowedMountArguments()
-{
-    return p->allowedMountArguments;
-}
-#endif
-
 const QString Smb4KGlobal::findMountExecutable()
 {
     QStringList paths;
@@ -801,3 +788,60 @@ void Smb4KGlobal::wait(int time)
     QTimer::singleShot(time, &loop, SLOT(quit()));
     loop.exec();
 }
+
+const QString Smb4KGlobal::findMacAddress(const QString &ipAddress)
+{
+    QString macAddress, executable;
+
+#if defined(Q_OS_LINUX)
+    executable = QStandardPaths::findExecutable(QStringLiteral("ip"));
+#elif defined(Q_OS_FREEBSD) || defined(Q_OS_NETBSD)
+    QHostAddress address(ipAddress);
+
+    if (address.protocol() == QHostAddress::IPv4Protocol) {
+        executable = QStandardPaths::findExecutable(QStringLiteral("arp"));
+    } else if (address.protocol() == QHostAddress::IPv6Protocol) {
+        executable = QStandardPaths::findExecutable(QStringLiteral("ndp"));
+    }
+#endif
+
+    if (!executable.isEmpty()) {
+        QStringList command;
+        command << executable;
+#if defined(Q_OS_LINUX)
+        command << QStringLiteral("neighbor");
+        command << QStringLiteral("show");
+#elif defined(Q_OS_FREEBSD) || defined(Q_OS_NETBSD)
+        command << QStringLiteral("-an");
+#endif
+
+        KProcess process;
+        process.setProgram(command);
+        process.setOutputChannelMode(KProcess::SeparateChannels);
+
+        if (process.execute(-1) >= 0) {
+            QStringList result = QString::fromLocal8Bit(process.readAllStandardOutput()).split(QStringLiteral("\n"));
+
+            for (const QString &r : result) {
+#if defined(Q_OS_LINUX)
+                if (r.section(QStringLiteral(" "), 0, 0) == ipAddress) {
+                    macAddress = r.section(QStringLiteral(" "), 4, 4);
+                    break;
+                }
+#elif defined(Q_OS_FREEBSD) || defined(Q_OS_NETBSD)
+                if (address.protocol() == QHostAddress::IPv4Protocol
+                    && r.section(QStringLiteral(" "), 1, 1).remove(QStringLiteral("(")).remove(QStringLiteral(")")) == ipAddress) {
+                    macAddress = r.simplified().section(QStringLiteral(" "), 3, 3);
+                    break;
+                } else if (address.protocol() == QHostAddress::IPv6Protocol
+                           && r.section(QStringLiteral(" "), 0, 0).section(QStringLiteral("%"), 0, 0) == ipAddress) {
+                    macAddress = r.simplified().section(QStringLiteral(" "), 1, 1);
+                    break;
+                }
+#endif
+            }
+        }
+    }
+
+    return macAddress;
+}
