@@ -2,7 +2,7 @@
     This class derives from QObject and encapsulates a bookmark item. It
     is for use with QtQuick.
 
-    SPDX-FileCopyrightText: 2013-2022 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
+    SPDX-FileCopyrightText: 2013-2024 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -199,6 +199,13 @@ public:
      */
     void setHostIpAddress(const QString &ip);
 
+    /**
+     * Get the icon of the network bookmark.
+     *
+     * @returns the icon
+     */
+    Q_INVOKABLE QIcon icon() const;
+
 Q_SIGNALS:
     /**
      * This signal is emitted if something changed.
