@@ -15,7 +15,6 @@
 #include "core/smb4ksettings.h"
 #include "core/smb4kshare.h"
 #include "core/smb4ksynchronizer.h"
-#include "core/smb4kwalletmanager.h"
 #include "core/smb4kworkgroup.h"
 #include "smb4kbookmarkmenu.h"
 #include "smb4knetworkbrowserdockwidget.h"
@@ -131,12 +130,6 @@ void Smb4KMainWindow::setupStatusBar()
     m_progressBar->setAlignment(Qt::AlignCenter);
     m_progressBar->setVisible(false);
 
-    // Set the icon on the right side that represents the initial
-    // state of the wallet manager.
-    m_passwordIcon = new QLabel(statusBar());
-    m_passwordIcon->setContentsMargins(0, 0, 0, 0);
-    m_passwordIcon->setAlignment(Qt::AlignCenter);
-
     // The feedback icon.
     m_feedbackIcon = new QLabel(statusBar());
     m_feedbackIcon->setContentsMargins(0, 0, 0, 0);
@@ -144,9 +137,7 @@ void Smb4KMainWindow::setupStatusBar()
 
     statusBar()->addPermanentWidget(m_progressBar);
     statusBar()->addPermanentWidget(m_feedbackIcon);
-    statusBar()->addPermanentWidget(m_passwordIcon);
 
-    slotWalletManagerInitialized();
     setupMountIndicator();
 
     //
@@ -155,8 +146,6 @@ void Smb4KMainWindow::setupStatusBar()
     connect(Smb4KClient::self(), &Smb4KClient::aboutToStart, this, &Smb4KMainWindow::slotClientAboutToStart);
     connect(Smb4KClient::self(), &Smb4KClient::finished, this, &Smb4KMainWindow::slotClientFinished);
 
-    connect(Smb4KWalletManager::self(), &Smb4KWalletManager::initialized, this, &Smb4KMainWindow::slotWalletManagerInitialized);
-
     connect(Smb4KMounter::self(), &Smb4KMounter::mounted, this, &Smb4KMainWindow::slotVisualMountFeedback);
     connect(Smb4KMounter::self(), &Smb4KMounter::unmounted, this, &Smb4KMainWindow::slotVisualUnmountFeedback);
     connect(Smb4KMounter::self(), &Smb4KMounter::aboutToStart, this, &Smb4KMainWindow::slotMounterAboutToStart);
@@ -272,10 +261,6 @@ void Smb4KMainWindow::loadSettings()
 
     m_bookmarkMenu->refreshMenu();
 
-    // Check the state of the password handler and the wallet settings and
-    // set the pixmap in the status bar accordingly.
-    slotWalletManagerInitialized();
-
     // Set up the mount indicator icon.
     setupMountIndicator();
 }
@@ -291,7 +276,7 @@ void Smb4KMainWindow::saveSettings()
 
 bool Smb4KMainWindow::queryClose()
 {
-    if (!m_quitting && !qApp->isSavingSession() && isVisible()) {
+    if (!(m_quitting || QCoreApplication::closingDown()) && !qApp->isSavingSession() && isVisible()) {
         // This part has been copied from JuK application.
         KMessageBox::information(this,
                                  i18n("<qt>Closing the main window will keep Smb4K running in the system tray.<br>"
@@ -387,7 +372,7 @@ void Smb4KMainWindow::setupDynamicActionList(QDockWidget *dock)
             actionsList = m_sharesViewDockWidget->actionCollection()->actions();
         }
 
-        for (QAction *action : qAsConst(actionsList)) {
+        for (QAction *action : std::as_const(actionsList)) {
             if (action->objectName() == QStringLiteral("bookmark_action")) {
                 m_bookmarkMenu->setBookmarkActionEnabled(action->isEnabled());
                 connect(action, &QAction::changed, this, &Smb4KMainWindow::slotEnableBookmarkAction);
@@ -491,22 +476,6 @@ void Smb4KMainWindow::slotAddBookmarks()
     }
 }
 
-void Smb4KMainWindow::slotWalletManagerInitialized()
-{
-    if (Smb4KWalletManager::self()->useWalletSystem()) {
-        if (KIconLoader::global()->hasIcon(QStringLiteral("kwalletmanager"))) {
-            m_passwordIcon->setPixmap(KIconLoader::global()->loadIcon(QStringLiteral("kwalletmanager"), KIconLoader::Small, 0, KIconLoader::DefaultState));
-        } else {
-            m_passwordIcon->setPixmap(KIconLoader::global()->loadIcon(QStringLiteral("security-high"), KIconLoader::Small, 0, KIconLoader::DefaultState));
-        }
-
-        m_passwordIcon->setToolTip(i18n("The wallet is used."));
-    } else {
-        m_passwordIcon->setPixmap(KIconLoader::global()->loadIcon(QStringLiteral("dialog-password"), KIconLoader::Small, 0, KIconLoader::DefaultState));
-        m_passwordIcon->setToolTip(i18n("The password dialog is used."));
-    }
-}
-
 void Smb4KMainWindow::slotClientAboutToStart(const NetworkItemPtr &item, int process)
 {
     Q_ASSERT(item);
