@@ -1,7 +1,7 @@
 /*
     The network neighborhood browser dock widget
 
-    SPDX-FileCopyrightText: 2018-2023 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
+    SPDX-FileCopyrightText: 2018-2024 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -12,7 +12,6 @@
 #include "core/smb4kmounter.h"
 #include "core/smb4ksettings.h"
 #include "core/smb4kshare.h"
-#include "core/smb4kwalletmanager.h"
 #include "core/smb4kworkgroup.h"
 #include "smb4kbookmarkdialog.h"
 #include "smb4kcustomsettingseditor.h"
@@ -226,7 +225,7 @@ void Smb4KNetworkBrowserDockWidget::setupActions()
     //
     QList<QAction *> actionsList = m_actionCollection->actions();
 
-    for (QAction *action : qAsConst(actionsList)) {
+    for (QAction *action : std::as_const(actionsList)) {
         m_contextMenu->addAction(action);
     }
 }
@@ -367,7 +366,7 @@ void Smb4KNetworkBrowserDockWidget::slotItemSelectionChanged()
         int unmountedShares = selectedItems.size();
         int printerShares = 0;
 
-        for (QTreeWidgetItem *selectedItem : qAsConst(selectedItems)) {
+        for (QTreeWidgetItem *selectedItem : std::as_const(selectedItems)) {
             Smb4KNetworkBrowserItem *item = static_cast<Smb4KNetworkBrowserItem *>(selectedItem);
 
             if (item) {
@@ -550,7 +549,7 @@ void Smb4KNetworkBrowserDockWidget::slotWorkgroupMembers(const WorkgroupPtr &wor
             m_networkBrowser->findItems(workgroup->workgroupName(), Qt::MatchFixedString | Qt::MatchRecursive, Smb4KNetworkBrowser::Network);
         Smb4KNetworkBrowserItem *workgroupItem = nullptr;
 
-        for (QTreeWidgetItem *item : qAsConst(workgroups)) {
+        for (QTreeWidgetItem *item : std::as_const(workgroups)) {
             Smb4KNetworkBrowserItem *tempWorkgroup = static_cast<Smb4KNetworkBrowserItem *>(item);
 
             if (tempWorkgroup->type() == Workgroup && tempWorkgroup->workgroupItem()->workgroupName() == workgroup->workgroupName()) {
@@ -591,7 +590,7 @@ void Smb4KNetworkBrowserDockWidget::slotWorkgroupMembers(const WorkgroupPtr &wor
             QList<HostPtr> members = workgroupMembers(workgroup);
 
             if (!members.isEmpty()) {
-                for (const HostPtr &host : qAsConst(members)) {
+                for (const HostPtr &host : std::as_const(members)) {
                     bool foundHost = false;
 
                     for (int i = 0; i < workgroupItem->childCount(); ++i) {
@@ -638,7 +637,7 @@ void Smb4KNetworkBrowserDockWidget::slotShares(const HostPtr &host)
         QList<QTreeWidgetItem *> hosts = m_networkBrowser->findItems(host->hostName(), Qt::MatchFixedString | Qt::MatchRecursive, Smb4KNetworkBrowser::Network);
         Smb4KNetworkBrowserItem *hostItem = nullptr;
 
-        for (QTreeWidgetItem *item : qAsConst(hosts)) {
+        for (QTreeWidgetItem *item : std::as_const(hosts)) {
             Smb4KNetworkBrowserItem *tempHost = static_cast<Smb4KNetworkBrowserItem *>(item);
 
             if (tempHost->type() == Host && tempHost->hostItem()->workgroupName() == host->workgroupName()) {
@@ -679,7 +678,7 @@ void Smb4KNetworkBrowserDockWidget::slotShares(const HostPtr &host)
             QList<SharePtr> shares = sharedResources(host);
 
             if (!shares.isEmpty()) {
-                for (const SharePtr &share : qAsConst(shares)) {
+                for (const SharePtr &share : std::as_const(shares)) {
                     bool foundShare = false;
 
                     for (int i = 0; i < hostItem->childCount(); ++i) {
@@ -816,7 +815,7 @@ void Smb4KNetworkBrowserDockWidget::slotAuthentication(bool checked)
 
     QList<QTreeWidgetItem *> selectedItems = m_networkBrowser->selectedItems();
 
-    for (QTreeWidgetItem *selectedItem : qAsConst(selectedItems)) {
+    for (QTreeWidgetItem *selectedItem : std::as_const(selectedItems)) {
         Smb4KNetworkBrowserItem *item = static_cast<Smb4KNetworkBrowserItem *>(selectedItem);
 
         if (item) {
@@ -837,7 +836,7 @@ void Smb4KNetworkBrowserDockWidget::slotAddCustomSettings(bool checked)
 
     QList<QTreeWidgetItem *> selectedItems = m_networkBrowser->selectedItems();
 
-    for (QTreeWidgetItem *selectedItem : qAsConst(selectedItems)) {
+    for (QTreeWidgetItem *selectedItem : std::as_const(selectedItems)) {
         Smb4KNetworkBrowserItem *item = static_cast<Smb4KNetworkBrowserItem *>(selectedItem);
 
         QPointer<Smb4KCustomSettingsEditor> customSettingsEditor = new Smb4KCustomSettingsEditor(this);
@@ -855,7 +854,7 @@ void Smb4KNetworkBrowserDockWidget::slotPreview(bool checked)
 
     QList<QTreeWidgetItem *> selectedItems = m_networkBrowser->selectedItems();
 
-    for (QTreeWidgetItem *selectedItem : qAsConst(selectedItems)) {
+    for (QTreeWidgetItem *selectedItem : std::as_const(selectedItems)) {
         Smb4KNetworkBrowserItem *item = static_cast<Smb4KNetworkBrowserItem *>(selectedItem);
 
         if (item && item->type() == Share && !item->shareItem()->isPrinter()) {
@@ -876,7 +875,7 @@ void Smb4KNetworkBrowserDockWidget::slotPrint(bool checked)
 
     QList<QTreeWidgetItem *> selectedItems = m_networkBrowser->selectedItems();
 
-    for (QTreeWidgetItem *selectedItem : qAsConst(selectedItems)) {
+    for (QTreeWidgetItem *selectedItem : std::as_const(selectedItems)) {
         Smb4KNetworkBrowserItem *item = static_cast<Smb4KNetworkBrowserItem *>(selectedItem);
 
         if (item && item->shareItem()->isPrinter()) {
@@ -898,7 +897,7 @@ void Smb4KNetworkBrowserDockWidget::slotMountActionTriggered(bool checked)
     QList<QTreeWidgetItem *> selectedItems = m_networkBrowser->selectedItems();
     QList<SharePtr> unmountedShares, mountedShares;
 
-    for (QTreeWidgetItem *selectedItem : qAsConst(selectedItems)) {
+    for (QTreeWidgetItem *selectedItem : std::as_const(selectedItems)) {
         Smb4KNetworkBrowserItem *item = static_cast<Smb4KNetworkBrowserItem *>(selectedItem);
 
         if (item && item->type() == Share && !item->shareItem()->isPrinter()) {
@@ -907,20 +906,15 @@ void Smb4KNetworkBrowserDockWidget::slotMountActionTriggered(bool checked)
             } else {
                 if (item->shareItem()->isHomesShare()) {
                     QPointer<Smb4KHomesUserDialog> homesUserDialog = new Smb4KHomesUserDialog(this);
-                    bool proceed = false;
 
                     if (homesUserDialog->setShare(item->shareItem())) {
-                        // We want to get a return value here, so we use exec()
-                        if (homesUserDialog->exec() == QDialog::Accepted) {
-                            proceed = true;
+                        int returnValue = homesUserDialog->exec();
+                        delete homesUserDialog;
+
+                        if (returnValue == QDialog::Rejected) {
+                            continue;
                         }
                     }
-
-                    delete homesUserDialog;
-
-                    if (!proceed) {
-                        continue;
-                    }
                 }
 
                 unmountedShares << item->shareItem();
@@ -930,7 +924,9 @@ void Smb4KNetworkBrowserDockWidget::slotMountActionTriggered(bool checked)
 
     if (!mountedShares.isEmpty()) {
         Smb4KMounter::self()->unmountShares(mountedShares);
-    } else {
+    }
+
+    if (!unmountedShares.isEmpty()) {
         Smb4KMounter::self()->mountShares(unmountedShares);
     }
 }
@@ -1087,14 +1083,7 @@ void Smb4KNetworkBrowserDockWidget::slotStopSearch()
 
 void Smb4KNetworkBrowserDockWidget::slotSearchResults(const QList<SharePtr> &shares)
 {
-    //
-    // A global search finished
-    //
     m_searchRunning = false;
-
-    //
-    // Process the search results
-    //
     QTreeWidgetItemIterator it(m_networkBrowser);
 
     while (*it) {
@@ -1103,15 +1092,8 @@ void Smb4KNetworkBrowserDockWidget::slotSearchResults(const QList<SharePtr> &sha
         if (networkItem->type() == Share) {
             for (const SharePtr &share : shares) {
                 if (networkItem->shareItem() == share) {
-                    //
-                    // Select the search result
-                    //
                     networkItem->setSelected(true);
 
-                    //
-                    // Expand the branch of the network tree where a search result
-                    // was retrieved
-                    //
                     if (!networkItem->parent()->isExpanded()) {
                         m_networkBrowser->expandItem(networkItem->parent());
                     }
@@ -1126,9 +1108,9 @@ void Smb4KNetworkBrowserDockWidget::slotSearchResults(const QList<SharePtr> &sha
         it++;
     }
 
-    //
-    // Pass the search results to the search toolbar
-    //
+    QTreeWidgetItem *firstItem = m_networkBrowser->selectedItems().first();
+    m_networkBrowser->scrollToItem(firstItem, QTreeWidget::PositionAtCenter);
+
     m_searchToolBar->setSearchResults(shares);
 }
 
