@@ -1,7 +1,7 @@
 /*
     This is the shares view of Smb4K.
 
-    SPDX-FileCopyrightText: 2006-2022 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
+    SPDX-FileCopyrightText: 2006-2024 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -112,17 +112,10 @@ protected:
      */
     Qt::DropActions supportedDropActions() const override;
 
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     /**
      * Reimplemented to allow dragging.
      */
     QMimeData *mimeData(const QList<QListWidgetItem *> &list) const override;
-#else
-    /**
-     * Reimplemented to allow dragging.
-     */
-    QMimeData *mimeData(const QList<QListWidgetItem *> list) const override;
-#endif
 
     /**
      * Reimplemented to allow dragging.
